@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright (C) 2009 Junta de Andalucia
+# Copyright (C) 2009,2010 Junta de Andalucia
 # 
 # Authors:
 #   Roberto Majadas <roberto.majadas at openshine.com>
@@ -8,22 +8,23 @@
 #   Luis de Bethencourt <luibg at openshine.com>
 #   Pablo Vieytes <pvieytes at openshine.com>
 #
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public
-# License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
-
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
-
-# You should have received a copy of the GNU General Public
-# License along with this library; if not, write to the Free
-# Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2, or (at your option)
+# any later version.
 #
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
+# USA
 
 import os
+import dbus
 
 import gtk
 import pango
@@ -42,20 +43,21 @@ class AdminConsole:
         except:
             d = gtk.MessageDialog(None, gtk.DIALOG_MODAL, type=gtk.MESSAGE_WARNING, buttons=gtk.BUTTONS_OK)
             d.set_property("icon-name", "nanny")
-            d.set_markup(_("<b>Nanny daemon is not started</b>"))
+            d.set_markup("<b>%s</b>" % _("Nanny daemon is not started"))
             d.format_secondary_markup(_("To use the parental control, please start up the daemon."))
             d.run()
             d.destroy()
             raise Exception ('DBus not initialized')
 
-        nanny.client.common.Utils.glade_magic (self,
-                                    glade_file = os.path.join (nanny.client.gnome.admin.glade_files_dir, "nanny_admin_console.glade"),
+        nanny.client.common.Utils.ui_magic (self,
+                                    ui_file = os.path.join (nanny.client.gnome.admin.ui_files_dir, "nanny_admin_console.ui"),
                                     prefix = "nac")
 
         self.window.connect ('delete-event', self.__on_close_event)
         self.help_button.connect ('clicked', self.__on_help_button_clicked)
         self.close_button.connect ('clicked', self.__on_close_button_clicked)
         self.apply_button.connect ('clicked', self.__on_apply_button_clicked)
+        self.unlock_button.connect('clicked', self.__on_unlock_button_clicked)
 
         self.session_hoursday_checkbutton.connect ('toggled', self.__on_session_hoursday_checkbutton_toggled)
         self.session_hoursday_spinbutton.connect ('value-changed', self.__on_session_hoursday_spinbutton_changed)
@@ -68,6 +70,8 @@ class AdminConsole:
         self.im_hoursday_checkbutton.connect ('toggled', self.__on_im_hoursday_checkbutton_toggled)
         self.im_hoursday_spinbutton.connect ('value-changed', self.__on_im_hoursday_spinbutton_changed)
 
+        
+
         self.session_schedule_widget = nanny.client.gnome.admin.ScheduleCalendar()
         self.session_schedule_alignment.add (self.session_schedule_widget)
         self.session_schedule_alignment.show_all()
@@ -99,6 +103,49 @@ class AdminConsole:
         self.window.set_position (gtk.WIN_POS_CENTER)
         self.window.show_all ()
 
+        self.__lock_widgets()
+
+    def __lock_widgets(self) :
+        lock_status = self.dbus_client.is_unlocked()
+        if lock_status == True :
+            self.unlock_area.hide()
+        else:
+            self.unlock_area.show()
+
+        self.apply_button.set_sensitive(lock_status)
+
+        self.session_hoursday_checkbutton.set_sensitive(lock_status)
+        if lock_status == True:
+            self.session_hoursday_spinbutton.set_sensitive(self.session_hoursday_checkbutton.get_active())
+        else:
+            self.session_hoursday_spinbutton.set_sensitive(lock_status)
+
+        self.browser_configure_proxy_button.set_sensitive(lock_status)
+        self.browser_use_proxy_checkbutton.set_sensitive(lock_status)
+        self.browser_hoursday_checkbutton.set_sensitive(lock_status)
+        if lock_status == True:
+            self.browser_hoursday_spinbutton.set_sensitive(self.browser_hoursday_checkbutton.get_active())
+        else:
+            self.browser_hoursday_spinbutton.set_sensitive(lock_status)
+        
+        self.mail_hoursday_checkbutton.set_sensitive(lock_status)
+        self.mail_hoursday_spinbutton.set_sensitive(lock_status)
+        if lock_status == True:
+            self.mail_hoursday_spinbutton.set_sensitive(self.mail_hoursday_checkbutton.get_active())
+        else:
+            self.mail_hoursday_spinbutton.set_sensitive(lock_status)
+
+        self.im_hoursday_checkbutton.set_sensitive(lock_status)
+        if lock_status == True:
+            self.im_hoursday_spinbutton.set_sensitive(self.im_hoursday_checkbutton.get_active())
+        else:
+            self.im_hoursday_spinbutton.set_sensitive(lock_status)
+
+        self.session_schedule_widget.set_sensitive(lock_status)
+        self.browser_schedule_widget.set_sensitive(lock_status)
+        self.mail_schedule_widget.set_sensitive(lock_status)
+        self.im_schedule_widget.set_sensitive(lock_status)
+
     def __create_users_treeview (self):
         # UID
         col = gtk.TreeViewColumn ('uid')
@@ -276,7 +323,7 @@ class AdminConsole:
             if self.__config_changed:
                 dialog = gtk.MessageDialog(None, 0, gtk.MESSAGE_INFO, gtk.BUTTONS_YES_NO)
                 dialog.set_property("icon-name", "nanny")
-                dialog.set_markup (_('<b>User change</b>'))
+                dialog.set_markup ("<b>%s</b>" % _('You have made changes'))
                 dialog.format_secondary_markup (_("If you don't press the 'Apply' button, your changes will be lost.\nAre you sure?") )
                 dialog.set_default_response(gtk.RESPONSE_YES)
                 ret = dialog.run()
@@ -311,6 +358,8 @@ class AdminConsole:
             self.__selected_user_id = None
             self.window.set_title (_('Nanny Admin Console'))
 
+        self.__lock_widgets()
+
     def __on_session_hoursday_spinbutton_changed (self, widget, data=None):
         self.__config_changed = True
     def __on_session_hoursday_checkbutton_toggled (self, widget, data=None):
@@ -348,7 +397,15 @@ class AdminConsole:
             self.im_hoursday_spinbutton.set_sensitive (False)
 
     def __on_help_button_clicked (self, widget, data=None):
-        pass
+        try:
+            gtk.show_uri(None , "ghelp:nanny", gtk.get_current_event_time())
+        except:
+            os.system("yelp ghelp:nanny")
+
+
+    def __on_unlock_button_clicked (self, widget, data=None):
+        self.dbus_client.unlock()
+        self.__lock_widgets()
 
     def __on_close_button_clicked (self, widget, data=None):
         gtk.main_quit()
